# sumedha_matrix

## A simple package which performs matrix operations like addition of two matrices,their difference, transpose and much more

---

# Use the package in your project

### Install the package

```
pip install sumedha_matrix
```

### Using the package

```
import sumedha_matrix.matrix as matrix

matrix.mat_add()
```

---

Sumedha © 2023

> **Note**
> This is for a university project. Might not be maintained in future.
